@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -40,16 +31,19 @@ __license__ = "Apache License, Version 2.0"
 # imports the base (old) version of the async implementation
 # that should be compatible with all the available python
 # interpreters, base collection of async library
-from .async_old import * #@UnusedWildImport
+from .async_old import *  # @UnusedWildImport
 
 # verifies if the current python interpreter version supports
 # the new version of the async implementation and if that's the
 # case runs the additional import of symbols, this should override
 # most of the symbols that have just been created
-if is_neo(): from .async_neo import * #@UnusedWildImport
+if is_neo():
+    from .async_neo import *  # @UnusedWildImport
+
 
 def header_a():
     return await_wrap(header_a_())
 
+
 def ensure_a(*args, **kwargs):
     return await_wrap(ensure_a_(*args, **kwargs))
