@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -41,6 +32,7 @@ from . import meta
 from . import legacy
 from . import observer
 
+
 class Controller(legacy.with_meta(meta.Indexed, observer.Observable)):
     """
     Top level abstract controller class from which all the
@@ -62,12 +54,14 @@ class Controller(legacy.with_meta(meta.Indexed, observer.Observable)):
             return getattr(self.owner, name)
         raise AttributeError("'%s' not found" % name)
 
-    def register(self, lazy = False):
-        if lazy: return
+    def register(self, lazy=False):
+        if lazy:
+            return
         self.setup()
 
-    def unregister(self, lazy = False):
-        if lazy: return
+    def unregister(self, lazy=False):
+        if lazy:
+            return
         self.teardown()
 
     def setup(self):
