@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -43,6 +34,7 @@ import uuid
 from . import common
 from . import legacy
 
+
 class AppierException(Exception):
     """
     Top level exception to be used as the root of
@@ -80,32 +72,40 @@ class AppierException(Exception):
         self._uid = None
 
     def __str__(self):
-        if legacy.PYTHON_3: return self.__unicode__()
+        if legacy.PYTHON_3:
+            return self.__unicode__()
         is_unicode = legacy.is_unicode(self.message)
-        if is_unicode: return self.message.encode("utf-8")
+        if is_unicode:
+            return self.message.encode("utf-8")
         return self.message
 
     def __unicode__(self):
         is_unicode = legacy.is_unicode(self.message)
-        if not is_unicode: return self.message.decode("utf-8")
+        if not is_unicode:
+            return self.message.decode("utf-8")
         return self.message
 
-    def get_meta(self, name, default = None):
-        if not self.meta: return default
+    def get_meta(self, name, default=None):
+        if not self.meta:
+            return default
         return self.meta.get(name, default)
 
     def set_meta(self, name, value):
-        if not self.meta: self.meta = {}
+        if not self.meta:
+            self.meta = {}
         self.meta[name] = value
 
     def del_meta(self, name):
-        if not self.meta: return
-        if not name in self.meta: return
+        if not self.meta:
+            return
+        if not name in self.meta:
+            return
         del self.meta[name]
 
     @property
     def uid(self):
-        if self._uid: return self._uid
+        if self._uid:
+            return self._uid
         self._uid = uuid.uuid4()
         return self._uid
 
@@ -113,6 +113,7 @@ class AppierException(Exception):
         cls = self.__class__
         return common.util().camel_to_readable(cls.__name__)
 
+
 class OperationalError(AppierException):
     """
     Error raised for a runtime error and as a result
@@ -123,6 +124,7 @@ class OperationalError(AppierException):
 
     pass
 
+
 class SecurityError(AppierException):
     """
     Error used to indicate security problems that may
@@ -133,6 +135,7 @@ class SecurityError(AppierException):
 
     pass
 
+
 class AssertionError(OperationalError):
     """
     Error raised for failure to meet any pre-condition or
@@ -144,6 +147,7 @@ class AssertionError(OperationalError):
         kwargs["code"] = kwargs.get("code", None)
         OperationalError.__init__(self, *args, **kwargs)
 
+
 class ValidationError(OperationalError):
     """
     Error raised when a validation on the model fails
@@ -168,16 +172,19 @@ class ValidationError(OperationalError):
         self.set_meta("errors", self.errors)
 
     def __str__(self):
-        if legacy.PYTHON_3: return self.__unicode__()
+        if legacy.PYTHON_3:
+            return self.__unicode__()
         message = OperationalError.__str__(self)
         extended = common.is_devel()
-        if not extended: return message
+        if not extended:
+            return message
         errors_s = self.errors_s()
-        if not errors_s: return message
+        if not errors_s:
+            return message
         if self.model:
             message += " for model '%s' with id '%s'" % (
                 self.model.__class__._name(),
-                self.model._id if hasattr(self.model, "_id") else "unset"
+                self.model._id if hasattr(self.model, "_id") else "unset",
             )
         errors_s = errors_s.encode("utf-8")
         message += " (" + errors_s + ")"
@@ -186,32 +193,39 @@ class ValidationError(OperationalError):
     def __unicode__(self):
         message = OperationalError.__unicode__(self)
         extended = common.is_devel()
-        if not extended: return message
+        if not extended:
+            return message
         errors_s = self.errors_s()
-        if not errors_s: return message
+        if not errors_s:
+            return message
         if self.model:
             message += " for model '%s' with id '%s'" % (
                 self.model.__class__._name(),
-                self.model._id if hasattr(self.model, "_id") else "unset"
+                self.model._id if hasattr(self.model, "_id") else "unset",
             )
         message += " (" + errors_s + ")"
         return message
 
-    def errors_s(self, encoding = "utf-8"):
-        if not self.errors: return ""
+    def errors_s(self, encoding="utf-8"):
+        if not self.errors:
+            return ""
         buffer = []
         is_first = True
         for name, errors in legacy.iteritems(self.errors):
             for error in errors:
                 is_bytes = legacy.is_bytes(error)
-                if is_bytes: error = error.decode(encoding)
-                if is_first: is_first = False
-                else: buffer.append(", ")
+                if is_bytes:
+                    error = error.decode(encoding)
+                if is_first:
+                    is_first = False
+                else:
+                    buffer.append(", ")
                 buffer.append(name)
                 buffer.append(" => ")
                 buffer.append(error)
         return legacy.u("").join(buffer)
 
+
 class NotFoundError(OperationalError):
     """
     Error originated from an operation that was not able
@@ -223,6 +237,7 @@ class NotFoundError(OperationalError):
         kwargs["code"] = kwargs.get("code", 404)
         OperationalError.__init__(self, *args, **kwargs)
 
+
 class NotImplementedError(OperationalError):
     """
     Error to be raised when a certain feature or route is not
@@ -234,6 +249,7 @@ class NotImplementedError(OperationalError):
         kwargs["code"] = kwargs.get("code", 501)
         OperationalError.__init__(self, *args, **kwargs)
 
+
 class BaseInternalError(RuntimeError):
     """
     The base (internal) error class from which all the
@@ -250,35 +266,43 @@ class BaseInternalError(RuntimeError):
     that should be considered private in context, this
     should be structured data ready to be serializable """
 
-    def __init__(self, message, meta = None):
+    def __init__(self, message, meta=None):
         RuntimeError.__init__(self, message)
         self.message = message
         self.meta = meta
 
     def __str__(self):
-        if legacy.PYTHON_3: return self.__unicode__()
+        if legacy.PYTHON_3:
+            return self.__unicode__()
         is_unicode = legacy.is_unicode(self.message)
-        if is_unicode: return self.message.encode("utf-8")
+        if is_unicode:
+            return self.message.encode("utf-8")
         return self.message
 
     def __unicode__(self):
         is_unicode = legacy.is_unicode(self.message)
-        if not is_unicode: return self.message.decode("utf-8")
+        if not is_unicode:
+            return self.message.decode("utf-8")
         return self.message
 
-    def get_meta(self, name, default = None):
-        if not self.meta: return default
+    def get_meta(self, name, default=None):
+        if not self.meta:
+            return default
         return self.meta.get(name, default)
 
     def set_meta(self, name, value):
-        if not self.meta: self.meta = {}
+        if not self.meta:
+            self.meta = {}
         self.meta[name] = value
 
     def del_meta(self, name):
-        if not self.meta: return
-        if not name in self.meta: return
+        if not self.meta:
+            return
+        if not name in self.meta:
+            return
         del self.meta[name]
 
+
 class ValidationInternalError(BaseInternalError):
     """
     Error raised when a validation on the model fails
@@ -290,10 +314,11 @@ class ValidationInternalError(BaseInternalError):
     """ The name of the attribute that failed
     the validation, for latter reference """
 
-    def __init__(self, name, message, meta = None):
-        BaseInternalError.__init__(self, message, meta = meta)
+    def __init__(self, name, message, meta=None):
+        BaseInternalError.__init__(self, message, meta=meta)
         self.name = name
 
+
 class ValidationMultipleError(ValidationInternalError):
     """
     Exception/error considered to be equivalent to the
@@ -305,19 +330,22 @@ class ValidationMultipleError(ValidationInternalError):
     """ The sequence containing the multiple errors associated
     with the validation multiple error """
 
-    def __init__(self, name = None, message = None, meta = None):
-        ValidationInternalError.__init__(self, name, message , meta = meta)
+    def __init__(self, name=None, message=None, meta=None):
+        ValidationInternalError.__init__(self, name, message, meta=meta)
         self.errors = []
         self.set_meta("errors", self.errors)
 
     def add_error(self, name, message):
-        if not self.name: self.name = name
-        if not self.message: self.message = message
+        if not self.name:
+            self.name = name
+        if not self.message:
+            self.message = message
         self.errors.append((name, message))
 
     def add_exception(self, exception):
         self.add_error(exception.name, exception.message)
 
+
 class HTTPError(BaseInternalError):
     """
     Top level HTTP error raised whenever a bad response
@@ -335,33 +363,43 @@ class HTTPError(BaseInternalError):
     going to be used to cache the binary contents of the
     error associated with this exception (data) stream """
 
-    def __init__(self, error, code = None, message = None, extended = None, meta = None):
+    def __init__(self, error, code=None, message=None, extended=None, meta=None):
         message = message or "Problem in the HTTP request"
-        if extended == None: extended = common.is_devel()
-        if code: message = "[%d] %s" % (code, message)
+        if extended == None:
+            extended = common.is_devel()
+        if code:
+            message = "[%d] %s" % (code, message)
         if extended:
-            data = self.read(error = error)
-            try: data = data.decode("utf-8")
-            except Exception: data = legacy.str(data)
-            if data: message = message + "\n" + data if message else data
-        BaseInternalError.__init__(self, message, meta = meta)
+            data = self.read(error=error)
+            try:
+                data = data.decode("utf-8")
+            except Exception:
+                data = legacy.str(data)
+            if data:
+                message = message + "\n" + data if message else data
+        BaseInternalError.__init__(self, message, meta=meta)
         self.code = code
         self.error = error
 
-    def read(self, error = None):
+    def read(self, error=None):
         error = error or self.error
-        if not self._data == None: return self._data
+        if not self._data == None:
+            return self._data
         self._data = error.read()
         return self._data
 
-    def read_json(self, error = None):
+    def read_json(self, error=None):
         error = error or self.error
-        data = self.read(error = error)
-        if legacy.is_bytes(data): data = data.decode("utf-8")
-        try: data_j = json.loads(data)
-        except Exception: data_j = None
+        data = self.read(error=error)
+        if legacy.is_bytes(data):
+            data = data.decode("utf-8")
+        try:
+            data_j = json.loads(data)
+        except Exception:
+            data_j = None
         return data_j
 
+
 class APIError(BaseInternalError):
     """
     Highest level error for API related problems that may be
@@ -372,7 +410,8 @@ class APIError(BaseInternalError):
     def __init__(self, *args, **kwargs):
         message = kwargs.get("message", None)
         meta = kwargs.get("meta", None)
-        BaseInternalError.__init__(self, message, meta = meta)
+        BaseInternalError.__init__(self, message, meta=meta)
+
 
 class APIAccessError(APIError):
     """
@@ -392,6 +431,7 @@ class APIAccessError(APIError):
             kwargs["message"] = self.original.message
         APIError.__init__(self, *args, **kwargs)
 
+
 class OAuthAccessError(APIAccessError):
     """
     OAuth related problems that typically involve either outdated
