@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -40,6 +31,7 @@ __license__ = "Apache License, Version 2.0"
 from . import common
 from . import legacy
 
+
 class Ordered(type):
     """
     Metaclass to be used for classes where the
@@ -49,9 +41,12 @@ class Ordered(type):
 
     def __new__(cls, name, bases, attrs):
         new_cls = super(Ordered, cls).__new__(cls, name, bases, attrs)
-        new_cls._ordered = [(name, attrs.pop(name)) for name, value in\
-            legacy.eager(attrs.items()) if hasattr(value, "creation_counter")]
-        new_cls._ordered.sort(key = lambda item: item[1].creation_counter)
+        new_cls._ordered = [
+            (name, attrs.pop(name))
+            for name, value in legacy.eager(attrs.items())
+            if hasattr(value, "creation_counter")
+        ]
+        new_cls._ordered.sort(key=lambda item: item[1].creation_counter)
         new_cls._ordered = [name for name, value in new_cls._ordered]
         return new_cls
 
@@ -59,11 +54,12 @@ class Ordered(type):
         super(Ordered, cls).__init__(name, bases, attrs)
 
     def __cmp__(self, value):
-        return cmp(self.__name__, value.__name__) #@UndefinedVariable
+        return cmp(self.__name__, value.__name__)  # @UndefinedVariable
 
     def __lt__(self, value):
         return self.__name__.__lt__(value.__name__)
 
+
 class Indexed(type):
     """
     Meta class data type for the indexing of the various route
@@ -78,21 +74,26 @@ class Indexed(type):
         # retrieves the complete set of elements in the current set of attributes
         # that are marked with the "creation counter" and then sorts these same
         # elements according to that value (sorting by order of definition)
-        ordered = [(name, attrs.pop(name)) for name, value in\
-            legacy.eager(attrs.items()) if hasattr(value, "creation_counter")]
-        ordered.sort(key = lambda item: item[1].creation_counter)
+        ordered = [
+            (name, attrs.pop(name))
+            for name, value in legacy.eager(attrs.items())
+            if hasattr(value, "creation_counter")
+        ]
+        ordered.sort(key=lambda item: item[1].creation_counter)
 
         # in case there's no ordered related values there's nothing remaining
         # to be done under this class creation and so the created class must
         # be returned immediately to the caller method
-        if not ordered: return new_cls
+        if not ordered:
+            return new_cls
 
         # retrieves the reference to the current global application instance
         # and verifies if the global (cache) base registered value is defined
         # in case it's not defines it as it's going to be used to avoid the
         # duplicated registration of routes
         app = common.base().App
-        if not hasattr(app, "_BASE_REGISTERED"): app._BASE_REGISTERED = []
+        if not hasattr(app, "_BASE_REGISTERED"):
+            app._BASE_REGISTERED = []
         registered = app._BASE_REGISTERED
 
         # iterates over the complete set of ordered elements to be able to
@@ -102,7 +103,9 @@ class Indexed(type):
             # to be able to register each of them properly
             routes = function._routes if hasattr(function, "_routes") else []
             errors = function._errors if hasattr(function, "_errors") else []
-            exceptions = function._exceptions if hasattr(function, "_exceptions") else []
+            exceptions = (
+                function._exceptions if hasattr(function, "_exceptions") else []
+            )
             customs = function._customs if hasattr(function, "_customs") else []
 
             # iterates over the complete set of routes associated with the current
@@ -121,7 +124,8 @@ class Indexed(type):
                 # that's the situation continues the loop to be able to
                 # avoid duplicated route registration (possible with imports)
                 route_t = (method, url)
-                if route_t in registered: continue
+                if route_t in registered:
+                    continue
                 registered.append(route_t)
 
                 # adds the new route to the application using the provided/unpacked
@@ -130,11 +134,11 @@ class Indexed(type):
                     method,
                     url,
                     function,
-                    asynchronous = asynchronous,
-                    json = json,
-                    opts = opts,
-                    context = new_name,
-                    priority = priority
+                    asynchronous=asynchronous,
+                    json=json,
+                    opts=opts,
+                    context=new_name,
+                    priority=priority,
                 )
 
             for error in errors:
@@ -142,11 +146,11 @@ class Indexed(type):
                 app.add_error(
                     code,
                     function,
-                    scope = scope,
-                    json = json,
-                    opts = opts,
-                    context = new_name,
-                    priority = priority
+                    scope=scope,
+                    json=json,
+                    opts=opts,
+                    context=new_name,
+                    priority=priority,
                 )
 
             for exception in exceptions:
@@ -154,21 +158,17 @@ class Indexed(type):
                 app.add_exception(
                     exception,
                     function,
-                    scope = scope,
-                    json = json,
-                    opts = opts,
-                    context = new_name,
-                    priority = priority
+                    scope=scope,
+                    json=json,
+                    opts=opts,
+                    context=new_name,
+                    priority=priority,
                 )
 
             for custom in customs:
                 key, opts, priority = custom
                 app.add_custom(
-                    key,
-                    function,
-                    opts = opts,
-                    context = new_name,
-                    priority = priority
+                    key, function, opts=opts, context=new_name, priority=priority
                 )
 
         return new_cls
