@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -39,6 +30,7 @@ __license__ = "Apache License, Version 2.0"
 
 from . import util
 
+
 class Observable(object):
     """
     The base class that implements the observable
@@ -68,19 +60,22 @@ class Observable(object):
         return name_f
 
     @classmethod
-    def bind_g(cls, name, method, oneshot = False):
-        if oneshot: method.oneshot = oneshot
+    def bind_g(cls, name, method, oneshot=False):
+        if oneshot:
+            method.oneshot = oneshot
         name_f = cls.name_f(name)
         methods = cls._events_g.get(name_f, [])
         methods.append(method)
         cls._events_g[name_f] = methods
 
     @classmethod
-    def unbind_g(cls, name, method = None):
+    def unbind_g(cls, name, method=None):
         name_f = cls.name_f(name)
         methods = cls._events_g.get(name_f, [])
-        if method: methods.remove(method)
-        else: del methods[:]
+        if method:
+            methods.remove(method)
+        else:
+            del methods[:]
 
     @classmethod
     def trigger_g(cls, name, *args, **kwargs):
@@ -89,12 +84,16 @@ class Observable(object):
         methods = cls._events_g.get(name_f, [])
         for method in methods:
             method(*args, **kwargs)
-            if not hasattr(method, "oneshot"): continue
-            if not method.oneshot: continue
+            if not hasattr(method, "oneshot"):
+                continue
+            if not method.oneshot:
+                continue
             oneshots = [] if oneshots == None else oneshots
             oneshots.append(method)
-        if not oneshots: return
-        for oneshot in oneshots: cls.unbind_g(name, oneshot)
+        if not oneshots:
+            return
+        for oneshot in oneshots:
+            cls.unbind_g(name, oneshot)
 
     def build(self):
         pass
@@ -102,20 +101,25 @@ class Observable(object):
     def destroy(self):
         self.unbind_all()
 
-    def bind(self, name, method, oneshot = False):
-        if oneshot: method.oneshot = oneshot
+    def bind(self, name, method, oneshot=False):
+        if oneshot:
+            method.oneshot = oneshot
         methods = self._events.get(name, [])
         methods.append(method)
         self._events[name] = methods
 
-    def unbind(self, name, method = None):
+    def unbind(self, name, method=None):
         methods = self._events.get(name, [])
-        if method: methods.remove(method)
-        else: del methods[:]
+        if method:
+            methods.remove(method)
+        else:
+            del methods[:]
 
     def unbind_all(self):
-        if not hasattr(self, "_events"): return
-        for methods in self._events.values(): del methods[:]
+        if not hasattr(self, "_events"):
+            return
+        for methods in self._events.values():
+            del methods[:]
         self._events.clear()
 
     def trigger(self, name, *args, **kwargs):
@@ -127,10 +131,14 @@ class Observable(object):
         methods = self._events.get(name, [])
         for method in methods:
             method(*args, **kwargs)
-            if not hasattr(method, "oneshot"): continue
-            if not method.oneshot: continue
+            if not hasattr(method, "oneshot"):
+                continue
+            if not method.oneshot:
+                continue
             oneshots = [] if oneshots == None else oneshots
             oneshots.append(method)
         level.trigger_g(name, self, *args, **kwargs)
-        if not oneshots: return
-        for oneshot in oneshots: self.unbind(name, oneshot)
+        if not oneshots:
+            return
+        for oneshot in oneshots:
+            self.unbind(name, oneshot)
