@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -43,6 +34,7 @@ import logging
 
 from . import util
 
+
 class Part(object):
     """
     Abstract top level class for the "part" module infra-structure
@@ -53,11 +45,12 @@ class Part(object):
     features to it in a "transparent" way.
     """
 
-    def __init__(self, owner = None, *args, **kwargs):
+    def __init__(self, owner=None, *args, **kwargs):
         self.owner = owner
         self.loaded = False
         self._load_paths()
-        if owner: self.register(owner)
+        if owner:
+            self.register(owner)
 
     def __getattr__(self, name):
         if self.owner and hasattr(self.owner, name):
@@ -66,17 +59,22 @@ class Part(object):
 
     @classmethod
     def _merge_paths(cls, first, second):
-        if not isinstance(first, (list, tuple)): first = [first]
-        if not isinstance(second, (list, tuple)): second = [second]
-        if isinstance(first, tuple): first = list(first)
-        if isinstance(second, tuple): second = list(second)
+        if not isinstance(first, (list, tuple)):
+            first = [first]
+        if not isinstance(second, (list, tuple)):
+            second = [second]
+        if isinstance(first, tuple):
+            first = list(first)
+        if isinstance(second, tuple):
+            second = list(second)
         return first + second
 
     def name(self):
         cls = self.__class__
         cls_name = cls.__name__
         name = util.camel_to_underscore(cls_name)
-        if name.endswith("_part"): name = name[:-5]
+        if name.endswith("_part"):
+            name = name[:-5]
         return name
 
     def version(self):
@@ -84,14 +82,13 @@ class Part(object):
 
     def info(self):
         return dict(
-            name = self.name(),
-            version = self.version(),
-            class_name = self.class_name()
+            name=self.name(), version=self.version(), class_name=self.class_name()
         )
 
     def class_name(self):
         cls = self.__class__
-        if not self.__module__: return cls.__name__
+        if not self.__module__:
+            return cls.__name__
         return self.__module__ + "." + cls.__name__
 
     def register(self, owner):
@@ -119,8 +116,10 @@ class Part(object):
 
     @property
     def logger(self):
-        if self.owner: return self.owner.logger
-        else: return logging.getLogger()
+        if self.owner:
+            return self.owner.logger
+        else:
+            return logging.getLogger()
 
     def _load_paths(self):
         module = self.__class__.__module__
