@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -46,21 +37,21 @@ from . import amqp
 from . import legacy
 from . import exceptions
 
-class Queue(object):
 
+class Queue(object):
     def length(self):
         raise exceptions.NotImplementedError()
 
     def clear(self):
         raise exceptions.NotImplementedError()
 
-    def push(self, value, priority = None, identify = False):
+    def push(self, value, priority=None, identify=False):
         raise exceptions.NotImplementedError()
 
-    def pop(self, block = True, full = False):
+    def pop(self, block=True, full=False):
         raise exceptions.NotImplementedError()
 
-    def subscribe(self, callback, full = False):
+    def subscribe(self, callback, full=False):
         raise exceptions.NotImplementedError()
 
     def loop(self):
@@ -75,23 +66,20 @@ class Queue(object):
     def nack(self):
         raise exceptions.NotImplementedError()
 
-    def build_value(
-        self,
-        value,
-        priority = None,
-        identify = False,
-        reverse = False
-    ):
-        if identify: identifier = self.build_identifier()
-        else: identifier = None
-        if priority and reverse: priority *= -1
+    def build_value(self, value, priority=None, identify=False, reverse=False):
+        if identify:
+            identifier = self.build_identifier()
+        else:
+            identifier = None
+        if priority and reverse:
+            priority *= -1
         return (priority, identifier, value), identifier
 
     def build_identifier(self):
         return str(uuid.uuid4())
 
-class MemoryQueue(Queue):
 
+class MemoryQueue(Queue):
     def __init__(self):
         Queue.__init__(self)
         self._queue = []
@@ -102,25 +90,24 @@ class MemoryQueue(Queue):
     def clear(self):
         del self._queue[:]
 
-    def push(self, value, priority = None, identify = False):
+    def push(self, value, priority=None, identify=False):
         value, identifier = self.build_value(
-            value,
-            priority = priority,
-            identify = identify,
-            reverse = True
+            value, priority=priority, identify=identify, reverse=True
         )
         heapq.heappush(self._queue, value)
         return identifier
 
-    def pop(self, block = True, full = False):
+    def pop(self, block=True, full=False):
         priority, identifier, value = heapq.heappop(self._queue)
         return (priority, identifier, value) if full else value
 
-class MultiprocessQueue(Queue):
 
+class MultiprocessQueue(Queue):
     def __init__(self):
-        try: import queue
-        except ImportError: import Queue as queue
+        try:
+            import queue
+        except ImportError:
+            import Queue as queue
         Queue.__init__(self)
         self._queue = queue.PriorityQueue()
 
@@ -128,36 +115,35 @@ class MultiprocessQueue(Queue):
         return self._queue.qsize()
 
     def clear(self):
-        try: import queue
-        except ImportError: import Queue as queue
+        try:
+            import queue
+        except ImportError:
+            import Queue as queue
         self._queue = queue.PriorityQueue()
 
-    def push(self, value, priority = None, identify = False):
+    def push(self, value, priority=None, identify=False):
         value, identifier = self.build_value(
-            value,
-            priority = priority,
-            identify = identify,
-            reverse = True
+            value, priority=priority, identify=identify, reverse=True
         )
         self._queue.put(value)
         return identifier
 
-    def pop(self, block = True, full = False):
+    def pop(self, block=True, full=False):
         priority, identifier, value = self._queue.get(block)
         return (priority, identifier, value) if full else value
 
-class AMQPQueue(Queue):
 
+class AMQPQueue(Queue):
     def __init__(
         self,
-        url = None,
-        name = "default",
-        durable = False,
-        max_priority = 255,
-        encoder = "pickle",
-        protocol = 2,
-        encoding = "utf-8",
-        amqp = None
+        url=None,
+        name="default",
+        durable=False,
+        max_priority=255,
+        encoder="pickle",
+        protocol=2,
+        encoding="utf-8",
+        amqp=None,
     ):
         self.url = url
         self.name = name
@@ -170,33 +156,27 @@ class AMQPQueue(Queue):
         self._build()
 
     def clear(self):
-        self.channel.queue_purge(queue = self.name)
+        self.channel.queue_purge(queue=self.name)
 
-    def push(self, value, priority = None, identify = False):
+    def push(self, value, priority=None, identify=False):
         value, identifier = self.build_value(
-            value,
-            priority = priority,
-            identify = identify,
-            reverse = False
+            value, priority=priority, identify=identify, reverse=False
         )
         body = self._dump(value)
 
         self._add_callback(
             self.channel.basic_publish,
-            exchange = "",
-            routing_key = self.name,
-            body = body,
-            properties = amqp.properties(
-                delivery_mode = 2,
-                priority = value[0] or 0
-            )
+            exchange="",
+            routing_key=self.name,
+            body=body,
+            properties=amqp.properties(delivery_mode=2, priority=value[0] or 0),
         )
 
         return identifier
 
-    def pop(self, block = True, full = False):
+    def pop(self, block=True, full=False):
         _method, _properties, body = self.channel.basic_get(
-            queue = self.name, auto_ack = False
+            queue=self.name, auto_ack=False
         )
         priority, identifier, value = self._load(body)
         return (priority, identifier, value) if full else value
@@ -204,33 +184,33 @@ class AMQPQueue(Queue):
     def subscribe(
         self,
         callback,
-        full = False,
-        auto_ack = True,
-        exclusive = False,
-        consumer_tag = None,
-        arguments = None
+        full=False,
+        auto_ack=True,
+        exclusive=False,
+        consumer_tag=None,
+        arguments=None,
     ):
         def handler(channel, method, properties, body):
             priority, identifier, value = self._load(body)
             result = (priority, identifier, value) if full else value
-            ack = lambda: self.ack(delivery_tag = method.delivery_tag)
-            nack = lambda: self.nack(delivery_tag = method.delivery_tag)
+            ack = lambda: self.ack(delivery_tag=method.delivery_tag)
+            nack = lambda: self.nack(delivery_tag=method.delivery_tag)
             callback(result) if auto_ack else callback(result, ack, nack)
 
         self.channel.basic_consume(
-            queue = self.name,
-            on_message_callback = handler,
-            auto_ack = auto_ack,
-            exclusive = exclusive,
-            consumer_tag = consumer_tag,
-            arguments = arguments
+            queue=self.name,
+            on_message_callback=handler,
+            auto_ack=auto_ack,
+            exclusive=exclusive,
+            consumer_tag=consumer_tag,
+            arguments=arguments,
         )
 
-    def ack(self, delivery_tag = None):
-        self.channel.basic_ack(delivery_tag = delivery_tag)
+    def ack(self, delivery_tag=None):
+        self.channel.basic_ack(delivery_tag=delivery_tag)
 
-    def nack(self, delivery_tag = None):
-        self.channel.basic_nack(delivery_tag = delivery_tag)
+    def nack(self, delivery_tag=None):
+        self.channel.basic_nack(delivery_tag=delivery_tag)
 
     def loop(self):
         self.channel.start_consuming()
@@ -242,35 +222,37 @@ class AMQPQueue(Queue):
         return self._dumper(value)
 
     def _dump_pickle(self, value):
-        return legacy.cPickle.dumps(value, protocol = self.protocol)
+        return legacy.cPickle.dumps(value, protocol=self.protocol)
 
     def _dump_json(self, value):
         body = json.dumps(value)
-        return legacy.bytes(body, encoding = self.encoding)
+        return legacy.bytes(body, encoding=self.encoding)
 
     def _load(self, body):
         return self._loader(body)
 
     def _load_pickle(self, body):
-        if legacy.PYTHON_3: kwargs = dict(encoding = "bytes")
-        else: kwargs = dict()
+        if legacy.PYTHON_3:
+            kwargs = dict(encoding="bytes")
+        else:
+            kwargs = dict()
         return legacy.cPickle.loads(body, **kwargs)
 
     def _load_json(self, body):
-        if legacy.is_bytes(body): body = body.decode(self.encoding)
+        if legacy.is_bytes(body):
+            body = body.decode(self.encoding)
         return json.loads(body)
 
     def _build(self):
-        if not self.amqp: self.amqp = amqp.AMQP(url = self.url)
+        if not self.amqp:
+            self.amqp = amqp.AMQP(url=self.url)
         self.connection = self.amqp.get_connection()
         self.channel = self.connection.channel()
-        self.channel.basic_qos(prefetch_count = 1)
+        self.channel.basic_qos(prefetch_count=1)
         self.queue = self.channel.queue_declare(
-            queue = self.name,
-            durable = self.durable,
-            arguments = {
-                "x-max-priority" : self.max_priority
-            }
+            queue=self.name,
+            durable=self.durable,
+            arguments={"x-max-priority": self.max_priority},
         )
         self._dumper = getattr(self, "_dump_" + self.encoder)
         self._loader = getattr(self, "_load_" + self.encoder)
