@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -45,25 +36,34 @@ from . import legacy
 from . import typesf
 from . import exceptions
 
+
 def serialize(obj):
-    if isinstance(obj, model.Model): return obj.model
-    if isinstance(obj, typesf.AbstractType): return obj.json_v()
-    if type(obj) == type(None): return ""
+    if isinstance(obj, model.Model):
+        return obj.model
+    if isinstance(obj, typesf.AbstractType):
+        return obj.json_v()
+    if type(obj) == type(None):
+        return ""
     return legacy.UNICODE(obj)
 
-def serialize_csv(items, encoding = "utf-8", errors = "strict", delimiter = ";", strict = False):
+
+def serialize_csv(
+    items, encoding="utf-8", errors="strict", delimiter=";", strict=False
+):
     # verifies if the strict mode is active and there're no items defined
     # if that's the case an operational error is raised, otherwise an in
     # case the items are not provided the default (empty string) is returned
-    if strict and not items: raise exceptions.OperationalError(
-        message = "Empty items object provided, no keys available"
-    )
-    if not items: return str()
+    if strict and not items:
+        raise exceptions.OperationalError(
+            message="Empty items object provided, no keys available"
+        )
+    if not items:
+        return str()
 
     # builds the encoder taking into account the provided encoding string
     # value, this encoder will be used to encode each of the partial values
     # that is going to be set in the target CSV buffer
-    encoder = build_encoder(encoding, errors = errors)
+    encoder = build_encoder(encoding, errors=errors)
 
     # retrieves the first element and uses it to determine if the current
     # sequence to be serialized is map or sequence based
@@ -76,18 +76,19 @@ def serialize_csv(items, encoding = "utf-8", errors = "strict", delimiter = ";",
     # that in case the sequence is not map based the first element is ignored
     keys = first.keys() if is_map else first
     keys = legacy.eager(keys)
-    if is_map: keys.sort()
-    else: items = items[1:]
+    if is_map:
+        keys.sort()
+    else:
+        items = items[1:]
 
     # constructs the first row (names/keys row) using the gathered sequence of keys
     # and encoding them using the currently build encoder
-    keys_row = [encoder(key) if type(key) == legacy.UNICODE else\
-        key for key in keys]
+    keys_row = [encoder(key) if type(key) == legacy.UNICODE else key for key in keys]
 
     # creates the new string buffer and uses it as the basis for the construction of
     # the CSV writer object, writing then the already build first row
     buffer = legacy.StringIO()
-    writer = csv.writer(buffer, delimiter = delimiter)
+    writer = csv.writer(buffer, delimiter=delimiter)
     writer.writerow(keys_row)
 
     # iterates over the complete set of items to serialize each of it's attribute values
@@ -111,7 +112,8 @@ def serialize_csv(items, encoding = "utf-8", errors = "strict", delimiter = ";",
         # them in case they are defined as unicode based values
         for value in row:
             is_unicode = isinstance(value, legacy.UNICODE)
-            if is_unicode: value = encoder(value)
+            if is_unicode:
+                value = encoder(value)
             row_e.append(value)
 
         # writes the encoded based row sequence to the writer in order to output the
@@ -123,8 +125,9 @@ def serialize_csv(items, encoding = "utf-8", errors = "strict", delimiter = ";",
     result = buffer.getvalue()
     return result
 
-def serialize_ics(items, encoding = "utf-8", errors = "strict"):
-    encoder = build_encoder(encoding, errors = errors)
+
+def serialize_ics(items, encoding="utf-8", errors="strict"):
+    encoder = build_encoder(encoding, errors=errors)
 
     buffer = legacy.StringIO()
     buffer.write("BEGIN:VCALENDAR\r\n")
@@ -165,6 +168,9 @@ def serialize_ics(items, encoding = "utf-8", errors = "strict"):
     result = buffer.getvalue()
     return result
 
-def build_encoder(encoding, errors = "strict"):
-    if legacy.PYTHON_3: return lambda v: v
-    else: return lambda v: v if v == None else v.encode(encoding, errors = errors)
+
+def build_encoder(encoding, errors="strict"):
+    if legacy.PYTHON_3:
+        return lambda v: v
+    else:
+        return lambda v: v if v == None else v.encode(encoding, errors=errors)
