@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -41,8 +32,8 @@ import unittest
 
 import appier
 
-class MockPart(appier.Part):
 
+class MockPart(appier.Part):
     def version(self):
         return "1.0.0"
 
@@ -54,10 +45,10 @@ class MockPart(appier.Part):
         appier.Part.unload(self)
         self.owner.mock_loaded = False
 
-class PartTest(unittest.TestCase):
 
+class PartTest(unittest.TestCase):
     def setUp(self):
-        self.app = appier.App(parts = (MockPart,))
+        self.app = appier.App(parts=(MockPart,))
 
     def tearDown(self):
         self.app.unload()
