@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -41,8 +32,8 @@ import unittest
 
 import appier
 
-class PreferencesTest(unittest.TestCase):
 
+class PreferencesTest(unittest.TestCase):
     def setUp(self):
         self.app = appier.App()
 
@@ -89,7 +80,8 @@ class PreferencesTest(unittest.TestCase):
         try:
             preferences = appier.RedisPreferences.new()
         except Exception:
-            if not hasattr(self, "skipTest"): return
+            if not hasattr(self, "skipTest"):
+                return
             self.skipTest("No Redis server present")
 
         preferences["first"] = 1
