@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -41,8 +32,8 @@ import unittest
 
 import appier
 
-class QueuingTest(unittest.TestCase):
 
+class QueuingTest(unittest.TestCase):
     def test_memory(self):
         queue = appier.MemoryQueue()
         queue.clear()
@@ -58,25 +49,25 @@ class QueuingTest(unittest.TestCase):
         self.assertEqual(identifier, None)
         self.assertEqual(result, "hello")
 
-        identifier = queue.push("hello", identify = True)
+        identifier = queue.push("hello", identify=True)
 
         self.assertNotEqual(identifier, None)
 
-        priority, _identifier, result = queue.pop(full = True)
+        priority, _identifier, result = queue.pop(full=True)
 
         self.assertEqual(priority, None)
         self.assertEqual(_identifier, identifier)
         self.assertEqual(result, "hello")
 
-        identifier_1 = queue.push("hello 1", priority = 3, identify = True)
-        identifier_2 = queue.push("hello 2", priority = 1, identify = True)
-        identifier_3 = queue.push("hello 3", priority = 5, identify = True)
+        identifier_1 = queue.push("hello 1", priority=3, identify=True)
+        identifier_2 = queue.push("hello 2", priority=1, identify=True)
+        identifier_3 = queue.push("hello 3", priority=5, identify=True)
 
         self.assertEqual(queue.length(), 3)
 
-        _priority, _identifier_3, _result_3 = queue.pop(full = True)
-        _priority, _identifier_1, _result_1 = queue.pop(full = True)
-        _priority, _identifier_2, _result_2 = queue.pop(full = True)
+        _priority, _identifier_3, _result_3 = queue.pop(full=True)
+        _priority, _identifier_1, _result_1 = queue.pop(full=True)
+        _priority, _identifier_2, _result_2 = queue.pop(full=True)
 
         self.assertEqual(_result_1, "hello 1")
         self.assertEqual(_result_2, "hello 2")
@@ -100,25 +91,25 @@ class QueuingTest(unittest.TestCase):
         self.assertEqual(identifier, None)
         self.assertEqual(result, "hello")
 
-        identifier = queue.push("hello", identify = True)
+        identifier = queue.push("hello", identify=True)
 
         self.assertNotEqual(identifier, None)
 
-        priority, _identifier, result = queue.pop(full = True)
+        priority, _identifier, result = queue.pop(full=True)
 
         self.assertEqual(priority, None)
         self.assertEqual(_identifier, identifier)
         self.assertEqual(result, "hello")
 
-        identifier_1 = queue.push("hello 1", priority = 3, identify = True)
-        identifier_2 = queue.push("hello 2", priority = 1, identify = True)
-        identifier_3 = queue.push("hello 3", priority = 5, identify = True)
+        identifier_1 = queue.push("hello 1", priority=3, identify=True)
+        identifier_2 = queue.push("hello 2", priority=1, identify=True)
+        identifier_3 = queue.push("hello 3", priority=5, identify=True)
 
         self.assertEqual(queue.length(), 3)
 
-        _priority, _identifier_3, _result_3 = queue.pop(full = True)
-        _priority, _identifier_1, _result_1 = queue.pop(full = True)
-        _priority, _identifier_2, _result_2 = queue.pop(full = True)
+        _priority, _identifier_3, _result_3 = queue.pop(full=True)
+        _priority, _identifier_1, _result_1 = queue.pop(full=True)
+        _priority, _identifier_2, _result_2 = queue.pop(full=True)
 
         self.assertEqual(_result_1, "hello 1")
         self.assertEqual(_result_2, "hello 2")
@@ -131,7 +122,8 @@ class QueuingTest(unittest.TestCase):
         try:
             queue = appier.AMQPQueue()
         except Exception:
-            if not hasattr(self, "skipTest"): return
+            if not hasattr(self, "skipTest"):
+                return
             self.skipTest("No AMQP server present")
 
         queue.clear()
@@ -146,23 +138,23 @@ class QueuingTest(unittest.TestCase):
         self.assertEqual(identifier, None)
         self.assertEqual(result, "hello")
 
-        identifier = queue.push("hello", identify = True)
+        identifier = queue.push("hello", identify=True)
 
         self.assertNotEqual(identifier, None)
 
-        priority, _identifier, result = queue.pop(full = True)
+        priority, _identifier, result = queue.pop(full=True)
 
         self.assertEqual(priority, None)
         self.assertEqual(_identifier, identifier)
         self.assertEqual(result, "hello")
 
-        identifier_1 = queue.push("hello 1", priority = 3, identify = True)
-        identifier_2 = queue.push("hello 2", priority = 1, identify = True)
-        identifier_3 = queue.push("hello 3", priority = 5, identify = True)
+        identifier_1 = queue.push("hello 1", priority=3, identify=True)
+        identifier_2 = queue.push("hello 2", priority=1, identify=True)
+        identifier_3 = queue.push("hello 3", priority=5, identify=True)
 
-        _priority, _identifier_3, _result_3 = queue.pop(full = True)
-        _priority, _identifier_1, _result_1 = queue.pop(full = True)
-        _priority, _identifier_2, _result_2 = queue.pop(full = True)
+        _priority, _identifier_3, _result_3 = queue.pop(full=True)
+        _priority, _identifier_1, _result_1 = queue.pop(full=True)
+        _priority, _identifier_2, _result_2 = queue.pop(full=True)
 
         self.assertEqual(_result_1, "hello 1")
         self.assertEqual(_result_2, "hello 2")
