@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2021 Hive Solutions Lda.
+# Copyright (c) 2008-2024 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -22,16 +22,7 @@
 __author__ = "João Magalhães <joamag@hive.pt>"
 """ The author(s) of the module """
 
-__version__ = "1.0.0"
-""" The version of the module """
-
-__revision__ = "$LastChangedRevision$"
-""" The revision number of the module """
-
-__date__ = "$LastChangedDate$"
-""" The last change date of the module """
-
-__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2024 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -41,29 +32,27 @@ import unittest
 
 import appier
 
-class SerializeTest(unittest.TestCase):
 
+class SerializeTest(unittest.TestCase):
     def test_csv(self):
         result = appier.serialize_csv([["item"], ["hello world"]])
         self.assertEqual(result, "item\r\nhello world\r\n")
 
-        result = appier.serialize_csv([
-            [appier.legacy.u("item")],
-            [appier.legacy.u("hello world")]
-        ])
+        result = appier.serialize_csv(
+            [[appier.legacy.u("item")], [appier.legacy.u("hello world")]]
+        )
         self.assertEqual(result, "item\r\nhello world\r\n")
 
-        result = appier.serialize_csv([
-            [appier.legacy.u("item")],
-            [appier.legacy.u("你好世界")]
-        ])
+        result = appier.serialize_csv(
+            [[appier.legacy.u("item")], [appier.legacy.u("你好世界")]]
+        )
         self.assertEqual(result, "item\r\n你好世界\r\n")
 
-        result = appier.serialize_csv([dict(item = "hello world")])
+        result = appier.serialize_csv([dict(item="hello world")])
         self.assertEqual(result, "item\r\nhello world\r\n")
 
-        result = appier.serialize_csv([dict(item = appier.legacy.u("hello world"))])
+        result = appier.serialize_csv([dict(item=appier.legacy.u("hello world"))])
         self.assertEqual(result, "item\r\nhello world\r\n")
 
-        result = appier.serialize_csv([dict(item = appier.legacy.u("你好世界"))])
+        result = appier.serialize_csv([dict(item=appier.legacy.u("你好世界"))])
         self.assertEqual(result, "item\r\n你好世界\r\n")
